#
# spec file for package ibus-table
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ibus-table
Version:        1.9.17
Release:        lp150.1.6
Summary:        The Table engine for IBus platform
License:        LGPL-2.1+
Group:          System/I18n/Chinese
Url:            https://github.com/mike-fabian/ibus-table/
Source:         https://github.com/mike-fabian/ibus-table/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM marguerite@opensuse.org
# replace file() to open()
# Patch:          ibus-table-python3.patch
BuildRequires:  docbook-utils-minimal
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  gnome-common
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(python3)
Requires:       ibus >= 1.4.99
Requires:       python3
Requires:       python3-curses
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The package contains general Table engine for IBus platform.

%package devel
Summary:        Development package for ibus-table
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
This package contains the files required for the development of ibus-table.

%prep
%setup -q
# %patch -p1
chmod -x AUTHORS COPYING README

%build
export PYTHON=python3
NOCONFIGURE=1 ./autogen.sh
%configure --disable-static \
           --enable-additional \
           --libexecdir=%{_libdir}/ibus
make %{?_smp_mflags}

%install
make DESTDIR=${RPM_BUILD_ROOT} NO_INDEX=true install

%find_lang %{name}

%fdupes %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING README NEWS ChangeLog
%{_bindir}/%{name}-createdb
%{_ibus_libdir}/ibus-engine-table
%{_ibus_libdir}/ibus-setup-table
%{_datadir}/applications/ibus-setup-table.desktop
%{_datadir}/%{name}
%{_ibus_componentdir}/table.xml
%{_mandir}/man1/%{name}-createdb.1.gz
%{_datadir}/appdata/ibus-table.appdata.xml

%files devel
%defattr(-,root,root)
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Fri Dec 15 2017 hillwood@opensuse.org
- Update to 1.9.17. This update will fix boo#939462
  * Load .desktop file for ibus-setup-table correctly under Gnome Wayland
  * Set WM_CLASS of ibus-setup-table correctly
  * Avoid running initialization code of ibus_table_location.py
  * when using ibus-table-createdb.
  * Make it work on Python 3.6 (Unbreak sqlite on Python 3.6)
  * (Resolves: rhbz#1413580).
  * Update translations from zanata (ca, de, fr, uk updated)
  * Point to new home-page in the “About” tab.
  * Improve README
  * Fix bug in Unihan_Variants.txt, 乾 U+4E7E is both simplified and traditional
    Chinese (thanks to Heiher r@hev.cc)
  * When ignoring key release events, “False” should be returned, not “True”
  * Resolves: Resolves: rhbz#1369514
  * add ibus-table.appdata.xml and make it translatable
  * pull some new translations and updates from Zanata (ca, fr, pt_BR, and uk
    are new, ja, zh_CN, and zh_TW have updates).
- Drop ibus-table-python3.patch, It is needless.
* Sun Sep 28 2014 hillwood@linuxfans.org
- update to 1.8.11
  * Fix typo in variable name self_onechar -> self._onechar
  * Disable “onechar” (Phrase mode/Single char mode) option for non-CJK
    databases
  * Disable auto_commit option for tables which do not have RULES
  * Resolves: rhbz#1135759 - The rusle is broken with "Normal commit mode"
    See: https://bugzilla.redhat.com/show_bug.cgi?id=1135759
  * Pass IBus.KEY_KP_Enter to the application if the preedit is empty
  * Resolves: rhbz#1133424 - With the new "rusle" table in ibus-table-cyrillic,
    Keypad Enter problem
    See: https://bugzilla.redhat.com/show_bug.cgi?id=1133424
  * Ignore Shift+Space hotkey to switch fullwidth/halfwidth if the database
    is not for CJK
  * Move some options into a new tab “Details”
  * Disable properties related to fullwidth/halfwidth for non-CJK tables
  * Remove “Hide Candidates/Display Candidates” from the properties menu
  * Show keyboard shortcuts also in the property menu entries
  * Use the “notify::text” signal instead of “activate” on GtkEntry widget
  * Update Chinese .po files
  * Update German translation
  * Move the “Restore all defaults” button into the GtkButtonBox at bottom
  * Apply fix for 同 again to Unihan_Variants.txt, it is both simplified *and*
    traditional Chinese
  * And regenerate engine/chinese_variants.py.
  * Escape %% and _ if they are not intended as wildcards
  * Require Python >= 3.3
* Sat Jul 26 2014 i@marguerite.su
- update version 1.8.5
  * Always write xml output in UTF-8 encoding, not in the encoding
    of the current locale
- changes since 1.8.4
  * Tweak defaults for Chinese mode taken from the locale
  * Fix prompts for array30 table and don’t use prompts in pinyin mode
  * Make it possible to use select keys like F1, F2, F3 ...
  * For cangjie* and quick* tables: Use big5 order if the freq from
    the table is the same
- add ibus-table-python3.patch
  * replace file() to open()
* Sat Jul 26 2014 hillwood@linuxfans.org
- Switch python to python3
* Fri Jul  4 2014 hillwood@linuxfans.org
- Updateto 1.8.3, ibus-table >= 1.8.x has many improvements over 1.5.x
  * The database format is simplified which makes better matching
    possible. But because of the changed database format, the
    tables have to be rebuilt, i.e. packages like ibus-table-chinese
    and ibus-table-others have to be rebuilt against  ibus-table > 1.8.0.
  * Wildcard support added, wildcards like ? for single characters or *
    for many characters can be used. The wildcards can be configured
    in the setup tool, for example one can also use 'z' as a single character
    wildcard if desired.
  * Setup tool improved, several new options added, works with Gnome3 now.
  * Prompt characters are supported now, for example when using Cangjie,
    日, 月, 金, ... are displayed while typing instead of a, b, c, ...
  * Moving around in the preëdit works correctly now. One can commit
    the current candidate to preëdit with the left shift key or with
    the arrow keys, commit more characters to preëdit that way, then
    move around in the preëdit and see the full key sequences of the
    characters in the preëdit. This way one can check the
    key sequences if one used wildcards or pinyin mode to enter the
    characters.
  * Fix many bugs
* Fri Feb 14 2014 fcrozat@suse.com
- Fix missing capital on devel package group.
* Sun Dec 15 2013 swyear@gmail.com
- Add Requires: python-curses, ibus-engine-table need this module,
  but it is not installed in some system, e.g Live KDE
* Mon Jul  8 2013 hillwood@linuxfans.org
- Update to 1.5.0
  * Updated PO files.
  * Make page up/down keys configurable
* Sun Jan 13 2013 hillwood@linuxfans.org
- fix bnc#803488
* Wed Dec 19 2012 hillwood@linuxfans.org
- Update to 1.4.99.20121112
  * Updated PO files
* Fri Oct 12 2012 hillwood@linuxfans.org
- Update to 1.4.99.20121012
  * Updated PO files.
  * Merge remote-tracking branch 'mozbugbox/page-up-down-config' into
* Wed Oct  3 2012 hillwood@linuxfans.org
- update to 1.4.99.20121003, upstream did not provide more information.
* Fri Sep  7 2012 hillwood@linuxfans.org
- update to 1.4.99.20120904
  Package Maintainer: Please test before include this to your distro.
* Wed Jul  4 2012 swyear@gmail.com
- Add ibus as Requires
* Mon Jun 18 2012 hillwood@linuxfans.org
- update to 1.3.9.20110827
- better compatibility for ibus 1.4
* Tue Jun 14 2011 swyear@gmail.com
- Update to 1.3.0;
  major update for ibus-1.3.x infrastructure
- additional had move to package ibus-table-others
* Wed Mar 24 2010 tiwai@suse.de
- fix file list
* Fri Jan 29 2010 mxwu@novell.com
- Initial import.
